import Vue from 'vue'
import VueRouter from 'vue-router'
import NProgress from 'nprogress' // progress bar
import 'nprogress/nprogress.css'
import store from './store'
import { pages } from './views'
import { checkAuthority } from './utils/authority';


Vue.use(VueRouter)

const routes = [
  {
    path: '/',
    name: 'index',
    redirect: '/exception/indexWelcome', // /dashboard
    component: () => import('@/layout/index.vue'),
    children: [
      ...pages,
    ]
  },
  {
    path: '/login',
    name: 'login',
    component: () => import('@/views/Login.vue')
  },
  {
    path: '/exception',
    name: 'exception',
    component: () => import('@/layout/index.vue'),
    children: [
      {
        path: '404',
        name: 'notfound',
        component: () => import('@/views/NotFound.vue'),
      },
      {
        path: 'norights',
        name: 'norights',
        component: () => import('@/views/NoRights.vue'),
      },
      { // 显示欢迎语
        path: '/exception/indexWelcome',
        name: 'indexWelcome',
        component: () => import('@/views/indexWelcome.vue'),
        meta: {
          menuShow: false,
          title: '欢迎语',
        },
      },
    ]
  },
  {
    path: '*',
    redirect: { name: 'notfound' }
  }
]

const router = new VueRouter({ routes })

// 校验用户权限
router.beforeEach((to, from, next) => {
  NProgress.start()

  const toLogin = { name: 'login', query: { from: to.name } }
  const toIndex = { name: 'index' }
  const to403 = { name: 'norights' }

  // console.log(to)
  /**
   *  在 utils/index.js 文件里面，有一段代码是 获取用户信息的请求，
   *  当后端返回状态码 401 ，就跳转到 login页面，会出现无限死循环，不停的跳转 login 页面
   *  所以在这里判断 如果是路由是 login 就直接进行下一步
   */
  if (to.name === 'login') {
    return next()
  }

  // 尝试去获取人员
  store.dispatch('getUser').then(() => {

    // 校验权限
    if (checkAuthority(store.state, to.name)) {
      return to.name === 'login' || to.fullPath.indexOf('/exception') > -1 ? next(toIndex) : next()
    } else {
      return to.name === 'login' || to.fullPath.indexOf('/exception') > -1 ? next() : next(to403)
    }
  }).catch((err) => {
    window.console.error(err.message || err)
    return to.name === 'login' || to.fullPath.indexOf('/exception') > -1 ? next() : next(toLogin)
  })

})

router.afterEach(() => {
  NProgress.done()
})

export default router
