import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    pages: {},
    detail: {}
  },
  mutations: {
    updateList (state, payload) {
      state.pages = payload || {}
    },
    updateDetail (state, payload) {
      state.detail = payload.detail || {}
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', {})
    },
    getList ({ commit }, payload) {
      const api = lodash.get(apis, 'firstpage.list')
      interact(api, payload).then((data) => {
        commit('updateList', data)
      })
    },
    getDetail ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'firstpage.detail'), payload)
        interact(api).then((data) => {
          commit('updateDetail', data)
          resolve(data)
        }).catch(() => {
          reject()
        })
      })
    },
    addFirstPage ( _, payload) {
      const { onSuccess } = payload
      const api = lodash.get(apis, 'firstpage.edi.vue')
      interact(api, payload.detail).then((data) => {
        onSuccess(data)
      })
    },
    editFirstPage ( _, payload) {
      const { onSuccess } = payload
      const api = lodash.get(apis, 'firstpage.edit')
      interact(api, payload.detail).then((data) => {
        onSuccess(data)
      })
    },
    deleteFirstPage ( _, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'firstpage.delete'), payload)
        interact(api).then((data) => {
          resolve(data)
        }).catch(() => {
          reject()
        })
      })
    },
    refreshFirstPage ( _, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'firstpage.refresh')
        interact(api, payload).then((data) => {
          resolve(data)
        }).catch(() => {
          reject()
        })
      })
    }
  }
}
