import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    goodsList: [],
    goodsInfo: {},
    goodsTypes: [],
    goodsSpecs: [],
  },
  mutations: {
    updateList (state, payload) {
      state.goodsList = payload || []
    },
    updateInfo (state, payload) {
      state.goodsInfo = payload || {}
    },
    updateTypes (state, payload) {
      state.goodsTypes = payload || {}
    },
    updateSpecs (state, payload) {
      state.goodsSpecs = payload || {}
    }
  },
  actions: {
    getGoodsList ({ commit }, payload) {
      interact(apis.goods.profile.list, payload).then((data) => {
        commit('updateList', data)
      })
    },
    saveGoods (_, goods) {
      return interact(apis.goods.profile.save, window.JSON.stringify(goods))
    },
    updateGoods (_, goods) {
      return interact(apis.goods.profile.update, window.JSON.stringify(goods))
    },
    deleteGoods (_, goods) {
      return interact(replaceApiParams(apis.goods.profile.delete, { id: goods.goodsId }))
    },
    getGoodsByID (_, payload) {
      return interact(replaceApiParams(apis.goods.profile.get, { id: payload.id }))
    },

    getGoodTypes (_, payload) {
      return interact(apis.goods.type.list, payload)
    },
    saveGoodType (_, goodsType) {
      return interact(apis.goods.type.save, window.JSON.stringify(goodsType))
    },
    updateGoodType (_, goodsType) {
      return interact(apis.goods.type.update, window.JSON.stringify(goodsType))
    },
    deleteGoodType (_, goodsType) {
      return interact(replaceApiParams(apis.goods.type.delete, { id: goodsType.typeId }))
    },

    getGoodsSpecList (_, payload) {
      return interact(apis.goods.spec.list, payload)
    },
    saveGoodsSpec (_, goodsSpec) {
      return interact(apis.goods.spec.save, window.JSON.stringify(goodsSpec))
    },
    deleteGoodsSpec (_, goodsSpec) {
      return interact(replaceApiParams(apis.goods.spec.delete, { id: goodsSpec.specId }))
    },

    // getGoodSpecs ({ commit }, payload) {
    //   interact(apis.goodsManager.getGoodsSpecList, payload).then(res => {
    //     commit('updateSpecs', res)
    //   })
    // },
    // getGoodsByID ({ commit }, { id }) {
    //   interact(replaceApiParams(apis.goodsManager.getGoodsByID, { id })).then(res => {
    //     commit('updateInfo', res)
    //   })
    // },
    // addGoods ({ commit }, payload) {
    //   interact(apis.goodsManager.addGoods, payload).then(res => {
    //     commit('updateInfo', res)
    //   })
    // },
    // updateGoods (_, payload) {
    //   interact(replaceApiParams(apis.goodsManager.updateGoods, { id: payload.GoodsId }), payload).then(x => x)
    // },
    // delGoods (_, { id, callback }) {
    //   interact(replaceApiParams(apis.goodsManager.deleteGoods.url, { id: id })).then(callback)
    // },
    // setNull ({ commit }) {
    //   commit('updateInfo', {})
    // },
    // updateInfo ({ commit }, payload) {
    //   commit('updateInfo', payload)
    // }
  }
}
