import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    sysparam: {},
    detail: {}
  },
  mutations: {
    updateList (state, payload) {
      state.sysparam = payload
    },
    updateDetail (state, payload) {
      state.detail = payload
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', {})
    },
    getList ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'sysparam.list')
        interact(api, payload).then((data) => {
          commit('updateList', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    getDetail ({ commit }, payload) {
      const api = replaceApiParams(lodash.get(apis, 'sysparam.detail'), payload)
      interact(api).then((data) => {
        commit('updateDetail', data)
      })
    },
    editSysparam (_, payload) {
      const { onSuccess } = payload
      const api = replaceApiParams(lodash.get(apis, 'sysparam.edit'), payload)
      interact(api, payload.detail).then((data) => {
        onSuccess(data)
      })
    }
  }
}
